summaryrefslogtreecommitdiffstats
path: root/package/busybox/patches/240-udhcpc_retries.patch
diff options
context:
space:
mode:
Diffstat (limited to 'package/busybox/patches/240-udhcpc_retries.patch')
-rw-r--r--package/busybox/patches/240-udhcpc_retries.patch14
1 files changed, 7 insertions, 7 deletions
diff --git a/package/busybox/patches/240-udhcpc_retries.patch b/package/busybox/patches/240-udhcpc_retries.patch
index 81f120d8e..bfcc02b7f 100644
--- a/package/busybox/patches/240-udhcpc_retries.patch
+++ b/package/busybox/patches/240-udhcpc_retries.patch
@@ -1,6 +1,6 @@
--- a/networking/udhcp/dhcpc.c
+++ b/networking/udhcp/dhcpc.c
-@@ -363,7 +363,7 @@ int udhcpc_main(int argc UNUSED_PARAM, c
+@@ -380,7 +380,7 @@ int udhcpc_main(int argc UNUSED_PARAM, c
switch (state) {
case INIT_SELECTING:
@@ -8,13 +8,13 @@
+ if (!discover_retries || packet_num < discover_retries) {
if (packet_num == 0)
xid = random_xid();
-
-@@ -394,7 +394,7 @@ int udhcpc_main(int argc UNUSED_PARAM, c
+ /* broadcast */
+@@ -409,7 +409,7 @@ int udhcpc_main(int argc UNUSED_PARAM, c
+ packet_num = 0;
continue;
- case RENEW_REQUESTED:
case REQUESTING:
- if (packet_num < discover_retries) {
+ if (!discover_retries || packet_num < discover_retries) {
- /* send request packet */
- if (state == RENEW_REQUESTED) /* unicast */
- send_renew(xid, server_addr, requested_ip);
+ /* send broadcast select packet */
+ send_select(xid, server_addr, requested_ip);
+ timeout = discover_timeout;